"""
Module: 'platform' on micropython-v1.19.1-stm32
"""
# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'stm32', 'port': 'stm32', 'machine': 'PYBv1.1 with STM32F405RG', 'release': '1.19.1', 'nodename': 'pyboard', 'name': 'micropython', 'family': 'micropython', 'sysname': 'pyboard', 'version': '1.19.1'}
# Stubber: 1.5.6
from typing import Any


def libc_ver(*args, **kwargs) -> Any:
    ...


def platform(*args, **kwargs) -> Any:
    ...


def python_compiler(*args, **kwargs) -> Any:
    ...
