from typing import Any

MICROPY_PY_UTIME_TICKS_PERIOD: Any
_PASSTHRU: Any
clock: Any

def sleep_ms(t) -> None: ...
def sleep_us(t) -> None: ...
def ticks_ms(): ...
def ticks_us(): ...

ticks_cpu = ticks_us

def ticks_add(t, delta): ...
def ticks_diff(a, b): ...
