from collections import OrderedDict as OrderedDict, namedtuple as namedtuple
from typing import Any

class deque:
    maxlen: Any
    flags: Any
    d: Any
    def __init__(self, iterable, maxlen, flags: int = ...) -> None: ...
    def __len__(self): ...
    def append(self, x) -> None: ...
    def popleft(self): ...
